{"00000:1": "

    <div class="5grid-layout">\n    <div class="row">\n        <div class="12u">\n            <div id="banner">\n                <div class="image-box"><a href="#"><img src="/images/img06.jpg" alt=""></a>\n                    <div class="caption"> <span>Phasellus Etiam Consequat Lorem Ipsum Etiam Veroeros</span> <a href="#" class="button">Amet Consequat</a> </div>\n                </div>\n            </div>\n            <div class="shadow"><a href="#"><img src="/images/img07.jpg" width="1200" height="50" alt=""></a></div>\n        </div>\n    </div>\n</div>\n

\n"}